@@ -5,14 +5,15 @@ log = logging.getLogger(__name__)
 
 
 class Config:
-    def __init__(self, token, ip, port, password, presence, presence_type, publish_channel_id, admin_channels,
-                 chat_channel_id, chat_ignore_regex, count_channel_id, update_player_count_interval,
+    def __init__(self, token, ip, port, password, steam_port, presence, presence_type, publish_channel_id,
+                 admin_channels, chat_channel_id, chat_ignore_regex, count_channel_id, update_player_count_interval,
                  rcon_keep_alive_interval, log_connect_disconnect_notices, log_player_count_updates, log_rcon_messages,
                  log_rcon_keep_alive, include_timestamp, debug, scheduled_commands):
         self.token = token
         self.ip = ip
         self.port = port
         self.password = password
+        self.steam_port = steam_port
         self.presence = presence
         self.presence_type = presence_type
         self.publish_channel_id = publish_channel_id
@@ -36,6 +37,7 @@ class Config:
         ip = config['rcon_ip']
         port = config['rcon_port']
         password = config['rcon_password']
+        steam_port = config['steam_port']
 
         presence = config.get('bot_presence')
         presence_type = config.get('bot_presence_type', 'playing')
@@ -79,10 +81,11 @@ class Config:
             log.error(message)
             raise ValueError(message)
 
-        return Config(token, ip, port, password, presence, presence_type, publish_channel_id, admin_channels,
-                      chat_channel_id, chat_ignore_regex, count_channel_id, update_player_count_interval,
-                      rcon_keep_alive_interval, log_connect_disconnect_notices, log_player_count_updates,
-                      log_rcon_messages, log_rcon_keep_alive, include_timestamp, debug, scheduled_commands)
+        return Config(token, ip, port, password, steam_port, presence, presence_type, publish_channel_id,
+                      admin_channels, chat_channel_id, chat_ignore_regex, count_channel_id,
+                      update_player_count_interval, rcon_keep_alive_interval, log_connect_disconnect_notices,
+                      log_player_count_updates, log_rcon_messages, log_rcon_keep_alive, include_timestamp, debug,
+                      scheduled_commands)
 
     @staticmethod
     def check_channel_default(channel=None, channels: list = None):
